import click
from sicp.clone import run_apps_clone, run_61a_clone


@click.group()
def cli():
    """
    This is an experimental general-purpose 61A task runner.
    """
    pass


@cli.command()
@click.argument("repo")
@click.argument("dest", default="")
def clone(repo, dest):
    """Clone REPO to DEST.

    REPO is the name of the 61a repo to set up.
    Currently, "apps" and "cs61a" are supported.
    By default, DEST is set to the name of REPO.
    """
    if repo == "apps":
        run_apps_clone(dest if dest else "cs61a-apps")
    elif repo == "cs61a":
        run_61a_clone(dest if dest else "berkeley-cs61a")
    else:
        click.echo("No need to use sicp for that! Just git clone.", err=True)


if __name__ == "__main__":
    cli()



from sicp.common.shell_utils import sh
import os


def run_apps_clone(dir):
    print("========== Cloning cs61a-apps ==========")
    sh("git", "clone", "https://github.com/Cal-CS-61A-Staff/cs61a-apps", dir)

    print("====== Installing Black & Prettier =====")
    if "black" not in sh("pip3", "list", quiet=True).decode("utf-8"):
        sh("pip3", "install", "black")
    if "prettier" not in sh("npm", "list", "-g", quiet=True).decode("utf-8"):
        sh("npm", "install", "-g", "prettier")

    print("========== Linking .githooks ===========")
    os.chdir(dir)
    sh("chmod", "+x", ".githooks/pre-commit")
    sh("git", "config", "core.hooksPath", ".githooks")

    print("================ Done! =================")


def run_61a_clone(dir):
    print("======== Cloning berkeley-cs61a ========")
    sh("git", "clone", "https://github.com/Cal-CS-61A-Staff/berkeley-cs61a", dir)

    print("================ Done! =================")



import os
import subprocess
import sys
from contextlib import contextmanager
from shutil import rmtree
from typing import List


def sh(*args, env={}, capture_output=False, quiet=False):
    if quiet:
        out = subprocess.run(
            args, env={**os.environ, **env, "ENV": "dev"}, stdout=subprocess.PIPE
        )
    else:
        out = subprocess.run(
            args, env={**os.environ, **env, "ENV": "dev"}, capture_output=capture_output
        )
    if capture_output:
        print(out.stdout, file=sys.stdout)
        print(out.stderr, file=sys.stderr)
    out.check_returncode()
    return out.stdout


def clean_all_except(folders: List[str]):
    for dirpath, _, filenames in os.walk("."):
        dirnames = dirpath.split(os.sep)[1:]
        if not dirnames:
            for filename in filenames:
                os.remove(filename)
        elif dirnames[0] not in folders:
            rmtree(dirpath)


@contextmanager
def tmp_directory(*, clean=False):
    main_dir = os.getcwd()
    if clean:
        sh("rm", "-rf", "tmp")
        os.mkdir("tmp")
    try:
        os.chdir("tmp")
        yield None
    finally:
        os.chdir(main_dir)
